=========================
Welcome to Pharmpy |logo|
=========================

.. |logo| image:: Pharmpy_logo.svg
   :width: 100

Contents
========


.. toctree::
   :maxdepth: 4

   installation
   getting_started
   user_guide
   Documentation <reference/modules>
   development
   changelog
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

